==> openflowplugin-extension-nicira-0.7.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/group/input/original/group/buckets/bucket/action/action/NxActionDecNshTtlRpcUpdateGroupOriginalCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.original.group.buckets.bucket.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-dec-nsh-ttl-rpc-update-group-original-case {
 *   uses nx-action-dec-nsh-ttl-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-group/input/original-group/buckets/bucket/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-dec-nsh-ttl-rpc-update-group-original-case</i>
 *
 */
public interface NxActionDecNshTtlRpcUpdateGroupOriginalCase
    extends
    DataObject,
    Augmentable<NxActionDecNshTtlRpcUpdateGroupOriginalCase>,
    NxActionDecNshTtlGrouping,
    Action
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-dec-nsh-ttl-rpc-update-group-original-case");


}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/group/input/original/group/buckets/bucket/action/action/NxActionDecNshTtlRpcUpdateGroupOriginalCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.original.group.buckets.bucket.action.action;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-dec-nsh-ttl-rpc-update-group-original-case {
 *   uses nx-action-dec-nsh-ttl-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-group/input/original-group/buckets/bucket/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-dec-nsh-ttl-rpc-update-group-original-case</i>
 *
 */
public interface NxActionDecNshTtlRpcUpdateGroupOriginalCase
    extends
    DataObject,
    Augmentable<NxActionDecNshTtlRpcUpdateGroupOriginalCase>,
    NxActionDecNshTtlGrouping,
    Action
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-dec-nsh-ttl-rpc-update-group-original-case");


}
